@@ -14,3 +14,5 @@ json_type_error = "json type error"
 wrong_json_data_error = "can't parser json"
 
 html_generate_no_data_tag = "can't make html report, data is null?"
+# add command
+add_command_exception_tag = "command value type should be as method or function"
\ No newline at end of file
